=================
Wayland protocols
=================


Supported protocols
===================

Gabbia supports a number of Wayland protocols. Additional protocols may be
added in later versions if they make sense for Gabbia's intended use.

* `Idle inhibit <https://wayland.app/protocols/idle-inhibit-unstable-v1>`_
* `Idle notify <https://wayland.app/protocols/ext-idle-notify-v1>`_
* `WLR Data Control <https://wayland.app/protocols/wlr-data-control-unstable-v1>`_
* `WLR Export DMA-BUF <https://wayland.app/protocols/wlr-export-dmabuf-unstable-v1>`_
* `WLR Layer Shell <https://wayland.app/protocols/wlr-layer-shell-unstable-v1>`_
* `WLR Virtual Pointer <https://wayland.app/protocols/wlr-virtual-pointer-unstable-v1>`_
* `WLR Screencopy <https://wayland.app/protocols/wlr-screencopy-unstable-v1>`_
* `WLR Output Management <https://wayland.app/protocols/wlr-output-management-unstable-v1>`_
* `WLR Foreign Toplevel Management <https://wayland.app/protocols/wlr-foreign-toplevel-management-unstable-v1>`_
* `Virtual Keyboard <https://wayland.app/protocols/virtual-keyboard-unstable-v1>`_
* `Presentation time <https://wayland.app/protocols/presentation-time>`_
* `Viewporter <https://wayland.app/protocols/viewporter>`_
* `Single-pixel buffer <https://wayland.app/protocols/single-pixel-buffer-v1>`_
* `XDG Decoration <https://wayland.app/protocols/xdg-decoration-unstable-v1>`_
* `XDG Activation <https://wayland.app/protocols/xdg-activation-unstable-v1>`_
* `Relative Pointer <https://wayland.app/protocols/relative-pointer-unstable-v1>`_


Future protocols
================

Although Gabbia does not aim to support a wide range of protocols some may make
sense to be supported in future:

* `Text Input <https://wayland.app/protocols/text-input-unstable-v3>`_
* `Pointer Constraints <https://wayland.app/protocols/pointer-constraints-unstable-v1>`_
* `Cursor Shape <https://wayland.app/protocols/cursor-shape-v1>`_


Protocol proposals
==================

If Gabbia should support a protocol that is not listed here, you can submit
a suggestion via the `bug tracker <https://github.com/heuer/gabbia/issues>`_
